@@ -73,6 +73,7 @@ use constant PROCESS_PKGS_AND_DEPS => 2;
 
 use constant NONE => 0b00000000;
 use constant ALL => 0b00001111;
+use constant SELECTED => 0b00011111;
 use constant NEW => 0b00001000;
 use constant NOT_NEW => 0b00000111;
 use constant UPDATED => 0b00000100;
@@ -87,6 +88,15 @@ use constant NOT_MODIFIED => 0b00001010;
 use constant ORPHANS => 0b00010000;
 use constant NOT_ORPHANS => 0b00001111;
 
+use constant ICON_COLUMN => 0;
+use constant SOFT_COLUMN => 1;
+use constant AVAILABLE_PKG_COLUMN => 2;
+use constant INSTALLED_PKG_COLUMN => 3;
+use constant SELECTED_PKG_COLUMN => 4;
+
+use constant WITH_PKG_INFOS => 0;
+use constant WITH_SIZES => 1;
+
 ####################################################################
 sub new { 
 	my $self = {};
